{{ header }}

.. _10times1minute:

=========================
Getting started tutorials
=========================

.. toctree::
    :maxdepth: 1

    01_table_oriented
    02_read_write
    03_subset_data
    04_plotting
    05_add_columns
    06_calculate_statistics
    07_reshape_table_layout
    08_combine_dataframes
    09_timeseries
    10_text_data
